#' @importFrom dplyr %>%
#' @export
dplyr::`%>%`


#' @importFrom dplyr group_by
#' @export
dplyr::group_by

#' @importFrom pander pander
pander::pander
